# -*- coding: utf-8 -*-
#
# "TheVirtualBrain - Widgets" package
#
# (c) 2022-2023, TVB Widgets Team
#

from tvb.simulator.integrators import Integrator
from tvb.simulator.noise import Noise

from xai_components.base import xai_component, Component, InArg, OutArg
from xai_components.utils import print_component_summary, set_defaults, set_values


@xai_component(color='rgb(253, 225, 0)')
class HeunDeterministic(Component):
    from tvb.simulator.integrators import HeunDeterministic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    heunDeterministic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.HeunDeterministic)

    def execute(self, ctx) -> None:
        heunDeterministic = self.HeunDeterministic()

        set_values(self, heunDeterministic)
        self.heunDeterministic.value = heunDeterministic
        print_component_summary(self.heunDeterministic.value)


@xai_component(color='rgb(253, 225, 0)')
class HeunStochastic(Component):
    from tvb.simulator.integrators import HeunStochastic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]
    noise: InArg[Noise]

    heunStochastic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.HeunStochastic)

    def execute(self, ctx) -> None:
        heunStochastic = self.HeunStochastic()

        set_values(self, heunStochastic)
        self.heunStochastic.value = heunStochastic
        print_component_summary(self.heunStochastic.value)


@xai_component(color='rgb(253, 225, 0)')
class EulerDeterministic(Component):
    from tvb.simulator.integrators import EulerDeterministic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    eulerDeterministic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.EulerDeterministic)

    def execute(self, ctx) -> None:
        eulerDeterministic = self.EulerDeterministic()

        set_values(self, eulerDeterministic)
        self.eulerDeterministic.value = eulerDeterministic
        print_component_summary(self.eulerDeterministic.value)


@xai_component(color='rgb(253, 225, 0)')
class EulerStochastic(Component):
    from tvb.simulator.integrators import EulerStochastic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]
    noise: InArg[Noise]

    eulerStochastic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.EulerStochastic)

    def execute(self, ctx) -> None:
        eulerStochastic = self.EulerStochastic()

        set_values(self, eulerStochastic)
        self.eulerStochastic.value = eulerStochastic
        print_component_summary(self.eulerStochastic.value)


@xai_component(color='rgb(253, 225, 0)')
class RungeKutta4thOrderDeterministic(Component):
    from tvb.simulator.integrators import RungeKutta4thOrderDeterministic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    rungeKutta4thOrderDeterministic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.RungeKutta4thOrderDeterministic)

    def execute(self, ctx) -> None:
        rungeKutta4thOrderDeterministic = self.RungeKutta4thOrderDeterministic()

        set_values(self, rungeKutta4thOrderDeterministic)
        self.rungeKutta4thOrderDeterministic.value = rungeKutta4thOrderDeterministic
        print_component_summary(self.rungeKutta4thOrderDeterministic.value)


@xai_component(color='rgb(253, 225, 0)')
class Identity(Component):
    from tvb.simulator.integrators import Identity
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    identity: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.Identity)

    def execute(self, ctx) -> None:
        identity = self.Identity()

        set_values(self, identity)
        self.identity.value = identity
        print_component_summary(self.identity.value)


@xai_component(color='rgb(253, 225, 0)')
class IdentityStochastic(Component):
    from tvb.simulator.integrators import IdentityStochastic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]
    noise: InArg[Noise]

    identityStochastic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.IdentityStochastic)

    def execute(self, ctx) -> None:
        identityStochastic = self.IdentityStochastic()

        set_values(self, identityStochastic)
        self.identityStochastic.value = identityStochastic
        print_component_summary(self.identityStochastic.value)


@xai_component(color='rgb(253, 225, 0)')
class VODE(Component):
    from tvb.simulator.integrators import VODE
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    vODE: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.VODE)

    def execute(self, ctx) -> None:
        vODE = self.VODE()

        set_values(self, vODE)
        self.vODE.value = vODE
        print_component_summary(self.vODE.value)


@xai_component(color='rgb(253, 225, 0)')
class VODEStochastic(Component):
    from tvb.simulator.integrators import VODEStochastic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]
    noise: InArg[Noise]

    vODEStochastic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.VODEStochastic)

    def execute(self, ctx) -> None:
        vODEStochastic = self.VODEStochastic()

        set_values(self, vODEStochastic)
        self.vODEStochastic.value = vODEStochastic
        print_component_summary(self.vODEStochastic.value)


@xai_component(color='rgb(253, 225, 0)')
class Dopri5(Component):
    from tvb.simulator.integrators import Dopri5
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    dopri5: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.Dopri5)

    def execute(self, ctx) -> None:
        dopri5 = self.Dopri5()

        set_values(self, dopri5)
        self.dopri5.value = dopri5
        print_component_summary(self.dopri5.value)


@xai_component(color='rgb(253, 225, 0)')
class Dopri5Stochastic(Component):
    from tvb.simulator.integrators import Dopri5Stochastic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]
    noise: InArg[Noise]

    dopri5Stochastic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.Dopri5Stochastic)

    def execute(self, ctx) -> None:
        dopri5Stochastic = self.Dopri5Stochastic()

        set_values(self, dopri5Stochastic)
        self.dopri5Stochastic.value = dopri5Stochastic
        print_component_summary(self.dopri5Stochastic.value)


@xai_component(color='rgb(253, 225, 0)')
class Dop853(Component):
    from tvb.simulator.integrators import Dop853
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]

    dop853: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.Dop853)

    def execute(self, ctx) -> None:
        dop853 = self.Dop853()

        set_values(self, dop853)
        self.dop853.value = dop853
        print_component_summary(self.dop853.value)


@xai_component(color='rgb(253, 225, 0)')
class Dop853Stochastic(Component):
    from tvb.simulator.integrators import Dop853Stochastic
    dt: InArg[float]
    bounded_state_variable_indices: InArg[list]
    state_variable_boundaries: InArg[list]
    clamped_state_variable_indices: InArg[list]
    clamped_state_variable_values: InArg[list]
    noise: InArg[Noise]

    dop853Stochastic: OutArg[Integrator]

    def __init__(self):
        set_defaults(self, self.Dop853Stochastic)

    def execute(self, ctx) -> None:
        dop853Stochastic = self.Dop853Stochastic()

        set_values(self, dop853Stochastic)
        self.dop853Stochastic.value = dop853Stochastic
        print_component_summary(self.dop853Stochastic.value)


# -*- coding: utf-8 -*-
#
# "TheVirtualBrain - Widgets" package
#
# (c) 2022-2023, TVB Widgets Team
#

from tvb.datatypes.equations import Equation

from xai_components.base import xai_component, Component, InArg, OutArg
from xai_components.utils import print_component_summary, set_defaults, set_values


@xai_component(color='rgb(253, 225, 0)')
class DiscreteEquation(Component):
    from tvb.datatypes.equations import DiscreteEquation
    parameters: InArg[dict]

    discreteEquation: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.DiscreteEquation)

    def execute(self, ctx) -> None:
        discreteEquation = self.DiscreteEquation()

        set_values(self, discreteEquation)
        self.discreteEquation.value = discreteEquation
        print_component_summary(self.discreteEquation.value)


@xai_component(color='rgb(253, 225, 0)')
class LinearEquation(Component):
    from tvb.datatypes.equations import Linear
    parameters: InArg[dict]

    linear: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Linear)

    def execute(self, ctx) -> None:
        linear = self.Linear()

        set_values(self, linear)
        self.linear.value = linear
        print_component_summary(self.linear.value)


@xai_component(color='rgb(253, 225, 0)')
class Gaussian(Component):
    from tvb.datatypes.equations import Gaussian
    parameters: InArg[dict]

    gaussian: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Gaussian)

    def execute(self, ctx) -> None:
        gaussian = self.Gaussian()

        set_values(self, gaussian)
        self.gaussian.value = gaussian
        print_component_summary(self.gaussian.value)


@xai_component(color='rgb(253, 225, 0)')
class DoubleGaussian(Component):
    from tvb.datatypes.equations import DoubleGaussian
    parameters: InArg[dict]

    doubleGaussian: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.DoubleGaussian)

    def execute(self, ctx) -> None:
        doubleGaussian = self.DoubleGaussian()

        set_values(self, doubleGaussian)
        self.doubleGaussian.value = doubleGaussian
        print_component_summary(self.doubleGaussian.value)


@xai_component(color='rgb(253, 225, 0)')
class Sigmoid(Component):
    from tvb.datatypes.equations import Sigmoid
    parameters: InArg[dict]

    sigmoid: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Sigmoid)

    def execute(self, ctx) -> None:
        sigmoid = self.Sigmoid()

        set_values(self, sigmoid)
        self.sigmoid.value = sigmoid
        print_component_summary(self.sigmoid.value)


@xai_component(color='rgb(253, 225, 0)')
class GeneralizedSigmoid(Component):
    from tvb.datatypes.equations import GeneralizedSigmoid
    parameters: InArg[dict]

    generalizedSigmoid: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.GeneralizedSigmoid)

    def execute(self, ctx) -> None:
        generalizedSigmoid = self.GeneralizedSigmoid()

        set_values(self, generalizedSigmoid)
        self.generalizedSigmoid.value = generalizedSigmoid
        print_component_summary(self.generalizedSigmoid.value)


@xai_component(color='rgb(253, 225, 0)')
class Sinusoid(Component):
    from tvb.datatypes.equations import Sinusoid
    parameters: InArg[dict]

    sinusoid: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Sinusoid)

    def execute(self, ctx) -> None:
        sinusoid = self.Sinusoid()

        set_values(self, sinusoid)
        self.sinusoid.value = sinusoid
        print_component_summary(self.sinusoid.value)


@xai_component(color='rgb(253, 225, 0)')
class Cosine(Component):
    from tvb.datatypes.equations import Cosine
    parameters: InArg[dict]

    cosine: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Cosine)

    def execute(self, ctx) -> None:
        cosine = self.Cosine()

        set_values(self, cosine)
        self.cosine.value = cosine
        print_component_summary(self.cosine.value)


@xai_component(color='rgb(253, 225, 0)')
class Alpha(Component):
    from tvb.datatypes.equations import Alpha
    parameters: InArg[dict]

    alpha: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Alpha)

    def execute(self, ctx) -> None:
        alpha = self.Alpha()

        set_values(self, alpha)
        self.alpha.value = alpha
        print_component_summary(self.alpha.value)


@xai_component(color='rgb(253, 225, 0)')
class PulseTrain(Component):
    from tvb.datatypes.equations import PulseTrain
    parameters: InArg[dict]

    pulseTrain: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.PulseTrain)

    def execute(self, ctx) -> None:
        pulseTrain = self.PulseTrain()

        set_values(self, pulseTrain)
        self.pulseTrain.value = pulseTrain
        print_component_summary(self.pulseTrain.value)


@xai_component(color='rgb(253, 225, 0)')
class Gamma(Component):
    from tvb.datatypes.equations import Gamma
    parameters: InArg[dict]

    gamma: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.Gamma)

    def execute(self, ctx) -> None:
        gamma = self.Gamma()

        set_values(self, gamma)
        self.gamma.value = gamma
        print_component_summary(self.gamma.value)


@xai_component(color='rgb(253, 225, 0)')
class DoubleExponential(Component):
    from tvb.datatypes.equations import DoubleExponential
    parameters: InArg[dict]

    doubleExponential: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.DoubleExponential)

    def execute(self, ctx) -> None:
        doubleExponential = self.DoubleExponential()

        set_values(self, doubleExponential)
        self.doubleExponential.value = doubleExponential
        print_component_summary(self.doubleExponential.value)


@xai_component(color='rgb(253, 225, 0)')
class FirstOrderVolterra(Component):
    from tvb.datatypes.equations import FirstOrderVolterra
    parameters: InArg[dict]

    firstOrderVolterra: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.FirstOrderVolterra)

    def execute(self, ctx) -> None:
        firstOrderVolterra = self.FirstOrderVolterra()

        set_values(self, firstOrderVolterra)
        self.firstOrderVolterra.value = firstOrderVolterra
        print_component_summary(self.firstOrderVolterra.value)


@xai_component(color='rgb(253, 225, 0)')
class MixtureOfGammas(Component):
    from tvb.datatypes.equations import MixtureOfGammas
    parameters: InArg[dict]

    mixtureOfGammas: OutArg[Equation]

    def __init__(self):
        set_defaults(self, self.MixtureOfGammas)

    def execute(self, ctx) -> None:
        mixtureOfGammas = self.MixtureOfGammas()

        set_values(self, mixtureOfGammas)
        self.mixtureOfGammas.value = mixtureOfGammas
        print_component_summary(self.mixtureOfGammas.value)



# -*- coding: utf-8 -*-
#
# "TheVirtualBrain - Widgets" package
#
# (c) 2022-2023, TVB Widgets Team
#

from tvb.datatypes.connectivity import Connectivity

from xai_components.base import InArg, OutArg, Component, xai_component
from xai_components.utils import print_component_summary


@xai_component(color='rgb(85, 37, 130)')
class ConnectivityFromFile(Component):
    file_name: InArg[str]

    connectivity: OutArg[Connectivity]

    def __init__(self):
        self.done = False
        self.file_name = InArg('connectivity_76.zip')
        self.connectivity = OutArg(None)

    def execute(self, ctx) -> None:
        # imports
        from matplotlib import pyplot as plt
        from tvb.simulator.lab import connectivity

        self.connectivity.value = connectivity.Connectivity.from_file(self.file_name.value)
        print_component_summary(self.connectivity.value)

        plt.imshow(self.connectivity.value.weights, interpolation='none')
        plt.show()